Package: ModToppLeone
Type: Package
Title: Modified Topp-Leone Distribution: Properties, Estimation, and
        Applications
Version: 0.1.0
Authors@R: c(
    person("Shikhar", "Tyagi", email = "shikhar1093tyagi@gmail.com", role = c("aut", "cre"), comment = c(ORCID = "0000-0003-1606-0844")),
    person("Abhishek", "Tyagi", email = "abhishektyagi033@gmail.com", role = "aut"),
    person("Arvind", "Pandey", email = "arvindmzu@gmail.com", role = "aut"),
    person("Bhupendra", "Singh", email = "bhupendra.rana@gmail.com", role = "aut"),
    person("Vrijesh", "Tripathi", email = "vrijesh.tripathi@uwi.edu", role = "aut")
  )
Description: Provides density, cumulative distribution function, quantile function, random number generation, survival function, hazard rate function, statistical properties, classical point and interval estimation (maximum likelihood, ordinary least squares, weighted least squares, Cramer-von Mises, and maximum product of spacings), Bayesian estimation under symmetric and asymmetric loss functions (squared error, entropy, precautionary, and generalized entropy loss functions) with highest posterior density intervals, censoring schemes (random, Type-I, Type-II, and progressive Type-II censoring), and real data applications for the 'Modified Topp-Leone' distribution. Methods are based on Singh et al. (2025) <https://statassoc.or.th>, Cheng and Amin (1983) <doi:10.1111/j.2517-6161.1983.tb01267.x>, Swain et al. (1988) <doi:10.1080/00949658808811094>, Chen and Shao (1999) <doi:10.1080/10618600.1999.10474802>, and Balakrishnan and Aggarwala (2000) <doi:10.1007/978-1-4612-1178-5>.
License: GPL (>= 3)
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Depends: R (>= 3.5.0)
Imports: stats, graphics
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-08-05 02:51:05 UTC; shikhar tyagi
Author: Shikhar Tyagi [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-1606-0844>),
  Abhishek Tyagi [aut],
  Arvind Pandey [aut],
  Bhupendra Singh [aut],
  Vrijesh Tripathi [aut]
Maintainer: Shikhar Tyagi <shikhar1093tyagi@gmail.com>
Repository: CRAN
Date/Publication: 2026-08-09 08:40:18 UTC
