% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/estimation_classical.R
\name{classical_mtl}
\alias{classical_mtl}
\alias{mle_mtl}
\alias{ols_mtl}
\alias{wls_mtl}
\alias{cvm_mtl}
\alias{mps_mtl}
\alias{fit_mtl}
\title{Classical Estimation Methods for the Modified Topp-Leone Distribution}
\usage{
mle_mtl(x, conf.level = 0.95)

ols_mtl(x)

wls_mtl(x)

cvm_mtl(x)

mps_mtl(x)

fit_mtl(
  x,
  method = c("mle", "ols", "wls", "cvm", "mps", "all"),
  conf.level = 0.95
)
}
\arguments{
\item{x}{Vector of sample observations (\code{x > 0}).}

\item{conf.level}{Confidence level for interval estimation (default: 0.95).}

\item{method}{Estimation method: \code{"mle"}, \code{"ols"}, \code{"wls"}, \code{"cvm"}, \code{"mps"}, or \code{"all"}.}
}
\value{
A list or data frame containing point estimate, standard error, asymptotic confidence interval,
log-likelihood, AIC, BIC, CAIC, Kolmogorov-Smirnov test statistic, and associated p-value.
}
\description{
Point and interval estimation of the shape parameter \code{alpha} of the
Modified Topp-Leone (MTL) distribution using classical methods: Maximum Likelihood (MLE),
Ordinary Least Squares (OLS), Weighted Least Squares (WLS), Cramér-von Mises (CVM),
and Maximum Product of Spacings (MPS).
}
\examples{
set.seed(123)
sample_data <- rmtl(n = 50, alpha = 2.0)

# MLE Estimation
mle_mtl(x = sample_data)

# OLS and WLS Estimation
ols_mtl(x = sample_data)
wls_mtl(x = sample_data)

# CVM and MPS Estimation
cvm_mtl(x = sample_data)
mps_mtl(x = sample_data)

# Fit all classical methods simultaneously
fit_mtl(x = sample_data, method = "all")

}
\references{
Singh, B., Tyagi, S., Singh, R. P., and Tyagi, A. (2025). Modified Topp-Leone
Distribution: Properties, Classical and Bayesian Estimation with Application to COVID-19
and Reliability Data. \emph{Thailand Statistician}, 23(1), 72-96.

Cheng, R. C. H., and Amin, N. A. K. (1983). Estimating parameters in continuous univariate
distributions with a shifted origin. \emph{Journal of the Royal Statistical Society: Series B}, 45(3), 394-403.

Swain, J. J., Venkatraman, S., and Wilson, J. R. (1988). Least-squares estimation of distribution
functions in Johnson's translation system. \emph{Journal of Statistical Computation and Simulation}, 29(4), 271-297.
}
\author{
Shikhar Tyagi, Abhishek Tyagi, Arvind Pandey, Bhupendra Singh, Vrijesh Tripathi
}
