% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{real_datasets}
\alias{real_datasets}
\alias{dataset_air}
\alias{dataset_covid_india}
\alias{dataset_covid_france}
\title{Real Datasets used in Modified Topp-Leone Research Paper}
\format{
Numeric vectors containing positive observations:
\describe{
  \item{dataset_air}{Number of successive failures for the air conditioning system of each member in a fleet of 13 Boeing 720 jet airplanes (divided by 100 for fitting convenience).}
  \item{dataset_covid_india}{Daily new COVID-19 cases in India from 16 March 2021 to 16 April 2021 (divided by 10,000).}
  \item{dataset_covid_france}{Daily new COVID-19 cases in France from 5 August 2020 to 5 November 2020 (divided by 10,000).}
}

An object of class \code{numeric} of length 39.

An object of class \code{numeric} of length 50.
}
\usage{
dataset_air

dataset_covid_india

dataset_covid_france
}
\description{
Three real-world datasets examined in Singh et al. (2025) to illustrate the flexibility and
applicability of the Modified Topp-Leone distribution.
}
\examples{
data(dataset_air)
mle_mtl(dataset_air)

data(dataset_covid_india)
fit_mtl(dataset_covid_india, method = "all")

data(dataset_covid_france)
bayes_mtl(dataset_covid_france, prior = "noninformative")
}
\references{
Singh, B., Tyagi, S., Singh, R. P., and Tyagi, A. (2025). Modified Topp-Leone
Distribution: Properties, Classical and Bayesian Estimation with Application to COVID-19
and Reliability Data. \emph{Thailand Statistician}, 23(1), 72-96.

Cordeiro, G. M., and Lemonte, A. J. (2011). The beta-Birnbaum-Saunders distribution:
An improved distribution for fatigue life modelling. \emph{Computational Statistics & Data Analysis}, 55(3), 1445-1461.
}
\keyword{datasets}
